@@ -1,7 +1,7 @@
 /*
     This file is part of Akonadi Contact.
 
-    Copyright (C) 2016 Laurent Montel <montel@kde.org>
+    Copyright (C) 2016-2017 Laurent Montel <montel@kde.org>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -30,7 +30,7 @@ class AkonadiContactSelectTypeCombobox : public Akonadi::AkonadiContactComboBox
 {
     Q_OBJECT
 public:
-    explicit AkonadiContactSelectTypeCombobox(QWidget *parent = Q_NULLPTR);
+    explicit AkonadiContactSelectTypeCombobox(QWidget *parent = nullptr);
     ~AkonadiContactSelectTypeCombobox();
 
     QStringList selectTypeList() const;
