@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -94,7 +94,8 @@ void MailWidget::setMail(const KContacts::Email &email)
     if (value.contains(QStringLiteral("PREF"))) {
         setPreferred(true);
     }
-    Q_FOREACH (const QString &type, mMailType->selectTypeList()) {
+    const QStringList lst = mMailType->selectTypeList();
+    for (const QString &type : lst) {
         if (value.contains(type)) {
             mOldType = type;
             mMailType->setCurrentIndex(mMailType->findData(type));
@@ -124,9 +125,7 @@ KContacts::Email MailWidget::email()
             value.append(QStringLiteral("PREF"));
         }
     } else {
-        if (value.contains(QStringLiteral("PREF"))) {
-            value.removeAll(QStringLiteral("PREF"));
-        }
+        value.removeAll(QStringLiteral("PREF"));
     }
     if (!value.isEmpty()) {
         parameters.insert(QStringLiteral("type"), value);
