@@ -2,7 +2,7 @@
     This file is part of Akonadi Contact.
 
     Copyright (C) 2016 eyeOS S.L.U., a Telefonica company, sales@eyeos.com
-    Copyright (C) 2016 Laurent Montel <laurent.montel@kdab.com>
+    Copyright (C) 2016-2017 Laurent Montel <laurent.montel@kdab.com>
 
     This library is free software; you can redistribute it and/or modify it
     under the terms of the GNU Library General Public License as published by
@@ -25,6 +25,7 @@
 #include "../../im/imaddress.h"
 #include "../../im/improtocols.h"
 #include "../../utils/utils.h"
+#include "helper_p.h"
 
 #include <KContacts/Addressee>
 using namespace Akonadi;
@@ -41,13 +42,12 @@ MessagingWidgetLister::~MessagingWidgetLister()
 
 }
 
-
 void MessagingWidgetLister::loadContact(const KContacts::Addressee &contact)
 {
     IMAddress::List imaddresses;
     const QStringList customs = contact.customs();
 
-    foreach (const QString &custom, customs) {
+    for (const QString &custom : customs) {
         QString app, name, value;
         Akonadi::Utils::splitCustomField(custom, app, name, value);
 
@@ -56,7 +56,7 @@ void MessagingWidgetLister::loadContact(const KContacts::Addressee &contact)
                 const QString protocol = app;
                 const QStringList names = value.split(QChar(0xE000), QString::SkipEmptyParts);
 
-                foreach (const QString &name, names) {
+                for (const QString &name : names) {
                     //TODO preferred support ?
                     imaddresses << IMAddress(protocol, name, false);
                 }
@@ -90,20 +90,20 @@ void MessagingWidgetLister::storeContact(KContacts::Addressee &contact) const
     QMap<QString, QStringList> protocolMap;
 
     // fill map with all known protocols
-    foreach (const QString &protocol, IMProtocols::self()->protocols()) {
+    const QStringList lstProtocols = IMProtocols::self()->protocols();
+    for (const QString &protocol : lstProtocols) {
         protocolMap.insert(protocol, QStringList());
     }
 
     // add the configured addresses
-    foreach (const IMAddress &address, imaddresses) {
+    for (const IMAddress &address : qAsConst(imaddresses)) {
         protocolMap[address.protocol()].append(address.name());
     }
 
     // iterate over this list and modify the contact according
-    QMapIterator<QString, QStringList> it(protocolMap);
-    while (it.hasNext()) {
-        it.next();
-
+    QMap<QString, QStringList>::const_iterator it = protocolMap.cbegin();
+    const QMap<QString, QStringList>::const_iterator itEnd = protocolMap.cend();
+    for (; it != itEnd; ++it) {
         if (!it.value().isEmpty()) {
             contact.insertCustom(it.key(), QStringLiteral("All"), it.value().join(QString(0xE000)));
         } else {
