@@ -23,6 +23,7 @@
 #include "emailaddressselectionwidget.h"
 
 #include "emailaddressselection_p.h"
+#include "emailaddressselectionmodel.h"
 #include "emailaddressselectionproxymodel_p.h"
 
 #include <changerecorder.h>
@@ -54,7 +55,7 @@ class SearchLineEdit : public QLineEdit
 {
     Q_OBJECT
 public:
-    SearchLineEdit(QWidget *receiver, QWidget *parent = Q_NULLPTR)
+    SearchLineEdit(QWidget *receiver, QWidget *parent = nullptr)
         : QLineEdit(parent)
         , mReceiver(receiver)
     {
@@ -104,24 +105,8 @@ void EmailAddressSelectionWidget::Private::init()
 {
     // setup internal model if needed
     if (!mModel) {
-        Akonadi::Session *session = new Akonadi::Session("InternalEmailAddressSelectionWidgetModel", q);
-
-        Akonadi::ItemFetchScope scope;
-        scope.fetchFullPayload(true);
-        scope.fetchAttribute<Akonadi::EntityDisplayAttribute>();
-
-        Akonadi::ChangeRecorder *changeRecorder = new Akonadi::ChangeRecorder(q);
-        changeRecorder->setSession(session);
-        changeRecorder->fetchCollection(true);
-        changeRecorder->setItemFetchScope(scope);
-        changeRecorder->setCollectionMonitored(Akonadi::Collection::root());
-        changeRecorder->setMimeTypeMonitored(KContacts::Addressee::mimeType(), true);
-        changeRecorder->setMimeTypeMonitored(KContacts::ContactGroup::mimeType(), true);
-
-        Akonadi::ContactsTreeModel *model = new Akonadi::ContactsTreeModel(changeRecorder, q);
-//    model->setCollectionFetchStrategy( Akonadi::ContactsTreeModel::InvisibleFetch );
-
-        mModel = model;
+        Akonadi::EmailAddressSelectionModel *model = new Akonadi::EmailAddressSelectionModel(q);
+        mModel = model->model();
     }
 
     // setup ui
@@ -176,7 +161,7 @@ void EmailAddressSelectionWidget::Private::init()
 
 EmailAddressSelectionWidget::EmailAddressSelectionWidget(QWidget *parent)
     : QWidget(parent)
-    , d(new Private(true, this, 0))
+    , d(new Private(true, this, nullptr))
 {
 }
 
@@ -206,7 +191,7 @@ EmailAddressSelection::List EmailAddressSelectionWidget::selectedAddresses() con
     }
 
     const QModelIndexList selectedRows = d->mView->selectionModel()->selectedRows(0);
-    foreach (const QModelIndex &index, selectedRows) {
+    for (const QModelIndex &index : selectedRows) {
         EmailAddressSelection selection;
         selection.d->mName = index.data(EmailAddressSelectionProxyModel::NameRole).toString();
         selection.d->mEmailAddress = index.data(EmailAddressSelectionProxyModel::EmailAddressRole).toString();
